@@ -1,14 +1,21 @@
-/* lenb.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     LENB */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 integer lenb_(char *c__, ftnlen c_len)
 {
@@ -19,10 +26,9 @@ integer lenb_(char *c__, ftnlen c_len)
     integer i_len(char *, ftnlen);
 
     /* Local variables */
-    static integer n;
-    static logical lchar;
-    static integer lc;
+    static integer n, lc;
     static char cn[1], cs[1];
+    static logical lchar;
 
     *(unsigned char *)cn = '\0';
     *(unsigned char *)cs = ' ';
