@@ -1,7 +1,7 @@
 /*
  *	dclvnm
  *
- *    Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+ *    Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
  *
  */
 
@@ -9,7 +9,7 @@
 #include <string.h>
 
 #ifndef DCLVER
-#define DCLVER "dcl-ver.5"
+#define DCLVER "dcl-ver.7.0.1"
 #endif
 
 #ifndef WINDOWS
